BitmapIndex

Struct BitmapIndex 

pub struct BitmapIndex { /* private fields */ }
Roaring-bitmap-backed tag index.

Maps tag strings to roaring bitmaps for fast AND/OR/NOT set operations. Uses an internal u32 offset for each MemoryId.

Implementations

Source

impl BitmapIndex

pub fn new() -> Self

Creates a new empty bitmap index.

pub fn add_tag(&self, id: MemoryId, tag: &str)

Add a tag for the given memory id.

pub fn remove_tag(&self, id: MemoryId, tag: &str)

Remove a tag for the given memory id.

pub fn query_tag(&self, tag: &str) -> Vec<MemoryId>

Get all memory ids that have the given tag.

pub fn query_tags_and(&self, tags: &[&str]) -> Vec<MemoryId>

Get memory ids that have ALL given tags (intersection).

pub fn query_tags_or(&self, tags: &[&str]) -> Vec<MemoryId>

Get memory ids that have ANY of the given tags (union).

pub fn remove_all(&self, id: MemoryId)

Remove all tags for a given memory id.

Source

impl BitmapIndex

pub fn save(&self, path: &Path) -> MenteResult<()>

Save the bitmap index to a JSON file.

pub fn load(path: &Path) -> MenteResult<Self>

Load the bitmap index from a JSON file.